==> iTop-3.1.0-2-11973.zip: web/datamodels/2.x/itop-hub-connector/dictionaries/ru.dict.itop-hub-connector.php <==
<?php
/**
 * Локализация интерфейса Combodo iTop подготовлена сообществом iTop по-русски http://community.itop-itsm.ru.
 *
 * @author      Vladimir Kunin <v.b.kunin@gmail.com>
 * @link        http://community.itop-itsm.ru  iTop Russian Community
 * @link        https://github.com/itop-itsm-ru/itop-rus
 * @license     http://opensource.org/licenses/AGPL-3.0
 *
 */
Dict::Add('RU RU', 'Russian', 'Русский', array(
	// Dictionary entries go here
	'Menu:iTopHub' => 'iTop Hub',
	'Menu:iTopHub:Register' => 'Подключение к iTop Hub',
	'Menu:iTopHub:Register+' => 'Перейдите в iTop Hub, чтобы обновить ваш экземпляр '.ITOP_APPLICATION_SHORT,
	'Menu:iTopHub:Register:Description' => '<p>Get access to your community platform iTop Hub!</br>Find all the content and information you need, manage your instances through personalized tools & install more extensions.</br><br/>By connecting to the Hub from this page, you will push information about this '.ITOP_APPLICATION_SHORT.' instance into the Hub.</p>~~',
	'Menu:iTopHub:MyExtensions' => 'Установленные расширения',
	'Menu:iTopHub:MyExtensions+' => 'Расширения, развернутые на данном экземпляре '.ITOP_APPLICATION_SHORT,
	'Menu:iTopHub:BrowseExtensions' => 'Получить расширения из iTop Hub',
	'Menu:iTopHub:BrowseExtensions+' => 'Найдите дополнительные расширения на iTop Hub',
	'Menu:iTopHub:BrowseExtensions:Description' => '<p>Look into iTop Hub’s store, your one stop place to find wonderful '.ITOP_APPLICATION_SHORT.' extensions !</br>Find the ones that will help you customize and adapt '.ITOP_APPLICATION_SHORT.' to your processes.</br><br/>By connecting to the Hub from this page, you will push information about this '.ITOP_APPLICATION_SHORT.' instance into the Hub.</p>~~',
	'iTopHub:GoBtn' => 'Go To iTop Hub~~',
	'iTopHub:CloseBtn' => 'Close~~',
	'iTopHub:GoBtn:Tooltip' => 'Jump to www.itophub.io~~',
	'iTopHub:OpenInNewWindow' => 'Open iTop Hub in a new window~~',
	'iTopHub:AutoSubmit' => 'Don\'t ask me again. Next time, go to iTop Hub automatically.~~',
	'UI:About:RemoteExtensionSource' => 'iTop Hub~~',
	'iTopHub:Explanation' => 'By clicking this button you will be redirected to iTop Hub.~~',
	'iTopHub:BackupFreeDiskSpaceIn' => '%1$s free disk space in %2$s.~~',
	'iTopHub:FailedToCheckFreeDiskSpace' => 'Failed to check free disk space.~~',
	'iTopHub:BackupOk' => 'Backup Ok.~~',
	'iTopHub:BackupFailed' => 'Backup failed!~~',
	'iTopHub:Landing:Status' => 'Deployment status~~',
	'iTopHub:Landing:Install' => 'Deploying extensions...~~',
	'iTopHub:CompiledOK' => 'Compilation successful.~~',
	'iTopHub:ConfigurationSafelyReverted' => 'Error detected during deployment!<br/>'.ITOP_APPLICATION_SHORT.' configuration has NOT been modified.~~',
	'iTopHub:FailAuthent' => 'Authentication failed for this action.~~',
	'iTopHub:InstalledExtensions' => 'Extensions deployed on this instance~~',
	'iTopHub:ExtensionCategory:Manual' => 'Extensions deployed manually~~',
	'iTopHub:ExtensionCategory:Manual+' => 'The following extensions have been deployed by copying them manually in the %1$s directory of '.ITOP_APPLICATION_SHORT.':~~',
	'iTopHub:ExtensionCategory:Remote' => 'Extensions deployed from iTop Hub~~',
	'iTopHub:ExtensionCategory:Remote+' => 'The following extensions have been deployed from iTop Hub:~~',
	'iTopHub:NoExtensionInThisCategory' => 'There is no extension in this category~~',
	'iTopHub:NoExtensionInThisCategory+' => 'Browse iTop Hub to find the extensions that will help you customize and adapt '.ITOP_APPLICATION_SHORT.' to your processes !~~',
	'iTopHub:ExtensionNotInstalled' => 'Not installed~~',
	'iTopHub:GetMoreExtensions' => 'Get extensions from iTop Hub...~~',
	'iTopHub:LandingWelcome' => 'Congratulations! The following extensions were downloaded from iTop Hub and deployed into your '.ITOP_APPLICATION_SHORT.'.~~',
	'iTopHub:GoBackToITopBtn' => 'Go Back to '.ITOP_APPLICATION_SHORT.'~~',
	'iTopHub:Uncompressing' => 'Uncompressing extensions...~~',
	'iTopHub:InstallationWelcome' => 'Installation of the extensions downloaded from iTop Hub~~',
	'iTopHub:DBBackupLabel' => 'Instance backup~~',
	'iTopHub:DBBackupSentence' => 'Do a backup of the database and '.ITOP_APPLICATION_SHORT.' configuration before updating~~',
	'iTopHub:DeployBtn' => 'Deploy !~~',
	'iTopHub:DatabaseBackupProgress' => 'Instance backup...~~',
	'iTopHub:InstallationEffect:Install' => 'Version: %1$s will be installed.~~',
	'iTopHub:InstallationEffect:NoChange' => 'Version: %1$s already installed. Nothing will change.~~',
	'iTopHub:InstallationEffect:Upgrade' => 'Will be <b>upgraded</b> from version %1$s to version %2$s.~~',
	'iTopHub:InstallationEffect:Downgrade' => 'Will be <b>DOWNGRADED</b> from version %1$s to version %2$s.~~',
	'iTopHub:InstallationProgress:DatabaseBackup' => ITOP_APPLICATION_SHORT.' Instance backup...~~',
	'iTopHub:InstallationProgress:ExtensionsInstallation' => 'Installation of the extensions~~',
	'iTopHub:InstallationEffect:MissingDependencies' => 'This extension cannot be installed because of unmet dependencies.~~',
	'iTopHub:InstallationEffect:MissingDependencies_Details' => 'The extension requires the module(s): %1$s~~',
	'iTopHub:InstallationProgress:InstallationSuccessful' => 'Installation successful!~~',
	'iTopHub:InstallationStatus:Installed_Version' => '%1$s version: %2$s.~~',
	'iTopHub:InstallationStatus:Installed' => 'Installed~~',
	'iTopHub:InstallationStatus:Version_NotInstalled' => 'Version %1$s <b>NOT</b> installed.~~',
));

==> iTop-3.2.0-2-14758.zip: web/datamodels/2.x/itop-hub-connector/dictionaries/ru.dict.itop-hub-connector.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 * @author Vladimir Kunin <v.b.kunin@gmail.com>
 *
 */
Dict::Add('RU RU', 'Russian', 'Русский', [
	'Menu:iTopHub' => 'iTop Hub',
	'Menu:iTopHub:BrowseExtensions' => 'Получить расширения из iTop Hub',
	'Menu:iTopHub:BrowseExtensions+' => 'Найдите дополнительные расширения на iTop Hub',
	'Menu:iTopHub:BrowseExtensions:Description' => '<p>Look into iTop Hub’s store, your one stop place to find wonderful iTop extensions !<br>Find the ones that will help you customize and adapt '.ITOP_APPLICATION_SHORT.' to your processes.<br><br>By connecting to the Hub from this page, you will push information about this '.ITOP_APPLICATION_SHORT.' instance into the Hub.</p>',
	'Menu:iTopHub:MyExtensions' => 'Установленные расширения',
	'Menu:iTopHub:MyExtensions+' => 'Расширения, развернутые на данном экземпляре '.ITOP_APPLICATION_SHORT,
	'Menu:iTopHub:Register' => 'Подключение к iTop Hub',
	'Menu:iTopHub:Register+' => 'Перейдите в iTop Hub, чтобы обновить ваш экземпляр '.ITOP_APPLICATION_SHORT,
	'Menu:iTopHub:Register:Description' => '<p>Get access to your community platform iTop Hub!<br>Find all the content and information you need, manage your instances through personalized tools & install more extensions.<br><br>By connecting to the Hub from this page, you will push information about this '.ITOP_APPLICATION_SHORT.' instance into the Hub.</p>~~',
	'UI:About:RemoteExtensionSource' => 'iTop Hub~~',
	'iTopHub:AutoSubmit' => 'Don\'t ask me again. Next time, go to iTop Hub automatically.~~',
	'iTopHub:BackupFailed' => 'Backup failed!~~',
	'iTopHub:BackupFreeDiskSpaceIn' => '%1$s free disk space in %2$s.~~',
	'iTopHub:BackupOk' => 'Backup Ok.~~',
	'iTopHub:CloseBtn' => 'Close~~',
	'iTopHub:CompiledOK' => 'Compilation successful.~~',
	'iTopHub:ConfigurationSafelyReverted' => 'Error detected during deployment!<br>'.ITOP_APPLICATION_SHORT.' configuration has NOT been modified.~~',
	'iTopHub:DBBackupLabel' => 'Instance backup~~',
	'iTopHub:DBBackupSentence' => 'Do a backup of the database and '.ITOP_APPLICATION_SHORT.' configuration before updating~~',
	'iTopHub:DatabaseBackupProgress' => 'Instance backup...~~',
	'iTopHub:DeployBtn' => 'Deploy !~~',
	'iTopHub:Explanation' => 'By clicking this button you will be redirected to iTop Hub.~~',
	'iTopHub:ExtensionCategory:Manual' => 'Extensions deployed manually~~',
	'iTopHub:ExtensionCategory:Manual+' => 'The following extensions have been deployed by copying them manually in the %1$s directory of '.ITOP_APPLICATION_SHORT.':~~',
	'iTopHub:ExtensionCategory:Remote' => 'Extensions deployed from iTop Hub~~',
	'iTopHub:ExtensionCategory:Remote+' => 'The following extensions have been deployed from iTop Hub:~~',
	'iTopHub:ExtensionNotInstalled' => 'Not installed~~',
	'iTopHub:FailAuthent' => 'Authentication failed for this action.~~',
	'iTopHub:FailedToCheckFreeDiskSpace' => 'Failed to check free disk space.~~',
	'iTopHub:GetMoreExtensions' => 'Get extensions from iTop Hub...~~',
	'iTopHub:GoBackToITopBtn' => 'Go Back to '.ITOP_APPLICATION_SHORT.'~~',
	'iTopHub:GoBtn' => 'Go To iTop Hub~~',
	'iTopHub:GoBtn:Tooltip' => 'Jump to www.itophub.io~~',
	'iTopHub:InstallationEffect:Downgrade' => 'Will be <b>DOWNGRADED</b> from version %1$s to version %2$s.~~',
	'iTopHub:InstallationEffect:Install' => 'Version: %1$s will be installed.~~',
	'iTopHub:InstallationEffect:MissingDependencies' => 'This extension cannot be installed because of unmet dependencies.~~',
	'iTopHub:InstallationEffect:MissingDependencies_Details' => 'The extension requires the module(s): %1$s~~',
	'iTopHub:InstallationEffect:NoChange' => 'Version: %1$s already installed. Nothing will change.~~',
	'iTopHub:InstallationEffect:Upgrade' => 'Will be <b>upgraded</b> from version %1$s to version %2$s.~~',
	'iTopHub:InstallationProgress:DatabaseBackup' => ITOP_APPLICATION_SHORT.' Instance backup...~~',
	'iTopHub:InstallationProgress:ExtensionsInstallation' => 'Installation of the extensions~~',
	'iTopHub:InstallationProgress:InstallationSuccessful' => 'Installation successful!~~',
	'iTopHub:InstallationStatus:Installed' => 'Installed~~',
	'iTopHub:InstallationStatus:Installed_Version' => '%1$s version: %2$s.~~',
	'iTopHub:InstallationStatus:Version_NotInstalled' => 'Version %1$s <b>NOT</b> installed.~~',
	'iTopHub:InstallationWelcome' => 'Installation of the extensions downloaded from iTop Hub~~',
	'iTopHub:InstalledExtensions' => 'Extensions deployed on this instance~~',
	'iTopHub:Landing:Install' => 'Deploying extensions...~~',
	'iTopHub:Landing:Status' => 'Deployment status~~',
	'iTopHub:LandingWelcome' => 'Congratulations! The following extensions were downloaded from iTop Hub and deployed into your '.ITOP_APPLICATION_SHORT.'.~~',
	'iTopHub:NoExtensionInThisCategory' => 'There is no extension in this category~~',
	'iTopHub:NoExtensionInThisCategory+' => 'Browse iTop Hub to find the extensions that will help you customize and adapt '.ITOP_APPLICATION_SHORT.' to your processes !~~',
	'iTopHub:OpenInNewWindow' => 'Open iTop Hub in a new window~~',
	'iTopHub:Uncompressing' => 'Uncompressing extensions...~~',
]);
